.. _spkg_jsonschema_specifications:

jsonschema_specifications: The JSON Schema meta-schemas and vocabularies, exposed as a Registry
===============================================================================================

Description
-----------

The JSON Schema meta-schemas and vocabularies, exposed as a Registry

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/jsonschema-specifications/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_pip`
- :ref:`spkg_referencing`

Version Information
-------------------

package-version.txt::

    2025.4.1

version_requirements.txt::

    jsonschema-specifications

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install jsonschema-specifications

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i jsonschema_specifications

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-jsonschema-specifications


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
